==> wfde-3.01.09.tar.gz: wfde-3.01.09/include/WarIfUser.h <==
/**
*/

#ifndef WAR_IF_USER_H
#define WAR_IF_USER_H

/* SYSTEM INCLUDES */


/* PROJECT INCLUDES */

#ifndef WAR_IF_SITE_H
#   include "WarIfSite.h"
#endif

#ifndef WAR_USER_AUTH_H
#   include "WarUserAuth.h"
#endif


/* LOCAL INCLUDES */


/* FORWARD REFERENCES */

class WarIfAuthModule;

#ifdef __cplusplus
extern "C" 
{
#endif
/****************** BEGIN OLD STYLE C spesific ********/


/****************** END OLD STYLE C spesific **********/
#ifdef __cplusplus 
}
#endif

/****************** BEGIN C++ spesific ****************/

#ifdef __cplusplus

class WarIfUser : public WarSmartPointer
{
public:
    typedef std::basic_string<war_sysch_t> string_t;
    // LIFECYCLE
    // OPERATORS

    bool operator == (const WarIfUser& from) const
    {
        return mName == from.mName;
    }

    bool operator < (const WarIfUser& from) const 
    {
        return mName < from.mName;
    }
    
    // OPERATIONS

    void SetEnable(const bool doEnable = true) throw(WarException);

    war_if_options_ptr_t GetOptions();

    // CALLBACK
    // ACCESS

    WarIfAuthModule& GetIfAuth() throw(WarException); 

    // INQUIRY

    const string_t& GetUserName() const throw(WarException);
    war_ccsysstr_t GetAuthModuleName() const throw(WarException);
    bool IsEnabled() const throw(WarException);
    bool IsOriginEnabled() const throw(WarException);
    const WarWin32Registry& GetRegKey() throw(WarException);

    
protected:
    friend class WarIfAuthModule;
    WarIfUser(war_if_aut_module_ptr_t rAuthPtr,
        WarUserAuthData& rAutData);
    ~WarIfUser();

private:
    HKEY mRegRootHkey;
    war_registrypath_t mRegPath;
    WarWin32Registry mRegKey; // Not open by default
    war_if_aut_module_ptr_t mAuthPtr;

    // Cached information if mRegKey is not open
    string_t mName;
    bool mEnabled;
    bool bOriginDisabled;

    void NeedRegistry() throw(WarException);
};

/* INLINE METHODS */

/* EXTERNAL REFERENCES */

typedef WarPtrWrapper<WarIfUser> war_if_user_ptr_t;
typedef std::set<war_if_user_ptr_t> war_if_user_set_t;

#endif /* __cplusplus */

/****************** END C++ spesific ******************/

#endif  /* WAR_IF_USER_H_ */

==> wfde-3.01.10.tar.gz: wfde-3.01.10/include/WarIfUser.h <==
/**
*/

#ifndef WAR_IF_USER_H
#define WAR_IF_USER_H

/* SYSTEM INCLUDES */


/* PROJECT INCLUDES */

#ifndef WAR_IF_SITE_H
#   include "WarIfSite.h"
#endif

#ifndef WAR_USER_AUTH_H
#   include "WarUserAuth.h"
#endif


/* LOCAL INCLUDES */


/* FORWARD REFERENCES */

class WarIfAuthModule;

#ifdef __cplusplus
extern "C" 
{
#endif
/****************** BEGIN OLD STYLE C spesific ********/


/****************** END OLD STYLE C spesific **********/
#ifdef __cplusplus 
}
#endif

/****************** BEGIN C++ spesific ****************/

#ifdef __cplusplus

class WarIfUser : public WarSmartPointer
{
public:
    typedef std::basic_string<war_sysch_t> string_t;
    // LIFECYCLE
    // OPERATORS

    bool operator == (const WarIfUser& from) const
    {
        return mName == from.mName;
    }

    bool operator < (const WarIfUser& from) const 
    {
        return mName < from.mName;
    }
    
    // OPERATIONS

    void SetEnable(const bool doEnable = true) throw(WarException);

    war_if_options_ptr_t GetOptions();

    // CALLBACK
    // ACCESS

    WarIfAuthModule& GetIfAuth() throw(WarException); 

    // INQUIRY

    const string_t& GetUserName() const throw(WarException);
    war_ccsysstr_t GetAuthModuleName() const throw(WarException);
    bool IsEnabled() const throw(WarException);
    bool IsOriginEnabled() const throw(WarException);
    const WarWin32Registry& GetRegKey() throw(WarException);

    
protected:
    friend class WarIfAuthModule;
    WarIfUser(war_if_aut_module_ptr_t rAuthPtr,
        WarUserAuthData& rAutData);
    ~WarIfUser();

private:
    WarWin32Registry mRegKey; 
    war_if_aut_module_ptr_t mAuthPtr;

    // Cached information if mRegKey is not open
    string_t mName;
    bool mEnabled;
    bool bOriginDisabled;

    void NeedRegistry() throw(WarException);
};

/* INLINE METHODS */

/* EXTERNAL REFERENCES */

typedef WarPtrWrapper<WarIfUser> war_if_user_ptr_t;
typedef std::set<war_if_user_ptr_t> war_if_user_set_t;

#endif /* __cplusplus */

/****************** END C++ spesific ******************/

#endif  /* WAR_IF_USER_H_ */
